==> qtjambi-sql-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiSql/QSqlResult_shell.h <==
#ifndef QSQLRESULT_SHELL_H
#define QSQLRESULT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSql/qsqlresult.h>
#include <QtJambi/QtJambiAPI>
#include <QSize>
#include <QSqlError>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtSql/qsqldriver.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlrecord.h>
#include <QtSql/qtsqlglobal.h>
#include <QtJambi/RegistryAPI>


class QSqlResult_shell : public QSqlResult, public QtJambiShellInterface
{
public:
    QSqlResult_shell(const QSqlDriver* db0);
    ~QSqlResult_shell() override;

    void bindValue(const QString& placeholder0, const QVariant& val1, QSql::ParamType type2) override;
    void bindValue(int pos0, const QVariant& val1, QSql::ParamType type2) override;
    QVariant data(int i0) override;
    void detachFromResultSet() override;
    bool exec() override;
    bool execBatch(bool arrayBind0) override;
    bool fetch(int i0) override;
    bool fetchFirst() override;
    bool fetchLast() override;
    bool fetchNext() override;
    bool fetchPrevious() override;
    QVariant handle() const override;
    bool isNull(int i0) override;
    QVariant lastInsertId() const override;
    bool nextResult() override;
    int numRowsAffected() override;
    bool prepare(const QString& query0) override;
    QSqlRecord record() const override;
    bool reset(const QString& sqlquery0) override;
    bool savePrepare(const QString& sqlquery0) override;
    void setActive(bool a0) override;
    void setAt(int at0) override;
    void setForwardOnly(bool forward0) override;
    void setLastError(const QSqlError& e0) override;
    void setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy policy0) override;
    void setQuery(const QString& query0) override;
    void setSelect(bool s0) override;
    int size() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSqlResult_access : public QSqlResult
{
    void __qt_addBindValue_cref_QVariant_QSql_ParamType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject val0, jint type1);
    jint __qt_at(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_bindValueType_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring placeholder0) const;
    jint __qt_bindValueType_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0) const;
    jint __qt_bindingSyntax(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_boundValue_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring placeholder0) const;
    jobject __qt_boundValue_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0) const;
    jint __qt_boundValueCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_boundValueName_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0) const;
    jobject __qt_boundValues(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_driver(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_executedQuery(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasOutValues(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isActive(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isForwardOnly(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isSelect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isValid(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_lastError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_lastQuery(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_numericalPrecisionPolicy(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resetBindCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_bindValue_cref_QString_cref_QVariant_QSql_ParamType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring placeholder0, jobject val1, jint type2);
    void __qt_bindValue_int_cref_QVariant_QSql_ParamType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0, jobject val1, jint type2);
    jobject __qt_data_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint i0);
    void __qt_detachFromResultSet(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_exec(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_execBatch_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean arrayBind0);
    jboolean __qt_fetch_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint i0);
    jboolean __qt_fetchFirst(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_fetchLast(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_fetchNext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_fetchPrevious(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_handle(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isNull_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint i0);
    jobject __qt_lastInsertId(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_nextResult(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_numRowsAffected(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_prepare_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring query0);
    jobject __qt_record(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_reset_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring sqlquery0);
    jboolean __qt_savePrepare_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring sqlquery0);
    void __qt_setActive_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean a0);
    void __qt_setAt_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint at0);
    void __qt_setForwardOnly_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean forward0);
    void __qt_setLastError_cref_QSqlError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_setNumericalPrecisionPolicy_QSql_NumericalPrecisionPolicy(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint policy0);
    void __qt_setQuery_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring query0);
    void __qt_setSelect_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean s0);
    jint __qt_size(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    static inline const std::type_info& __registerEnumTypeInfo_BindingSyntax() {
        return RegistryAPI::registerEnumTypeInfo<QSqlResult::BindingSyntax>("QSqlResult::BindingSyntax", "io/qt/sql/QSqlResult$BindingSyntax");
    }
    static inline const std::type_info& __registerEnumTypeInfo_VirtualHookOperation() {
        return RegistryAPI::registerEnumTypeInfo<QSqlResult::VirtualHookOperation>("QSqlResult::VirtualHookOperation", "io/qt/sql/QSqlResult$VirtualHookOperation");
    }
};

#endif // QSQLRESULT_SHELL_H

==> qtjambi-sql-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiSql/QSqlResult_shell.h <==
#ifndef QSQLRESULT_SHELL_H
#define QSQLRESULT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSql/qsqlresult.h>
#include <QtJambi/QtJambiAPI>
#include <QSize>
#include <QSqlError>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtSql/qsqldriver.h>
#include <QtSql/qsqlerror.h>
#include <QtSql/qsqlrecord.h>
#include <QtSql/qtsqlglobal.h>
#include <QtJambi/RegistryAPI>


class QSqlResult_shell : public QSqlResult, public QtJambiShellInterface
{
public:
    QSqlResult_shell(const QSqlDriver* db0);
    ~QSqlResult_shell() override;

    void bindValue(const QString& placeholder0, const QVariant& val1, QSql::ParamType type2) override;
    void bindValue(int pos0, const QVariant& val1, QSql::ParamType type2) override;
    QVariant data(int i0) override;
    void detachFromResultSet() override;
    bool exec() override;
    bool execBatch(bool arrayBind0) override;
    bool fetch(int i0) override;
    bool fetchFirst() override;
    bool fetchLast() override;
    bool fetchNext() override;
    bool fetchPrevious() override;
    QVariant handle() const override;
    bool isNull(int i0) override;
    QVariant lastInsertId() const override;
    bool nextResult() override;
    int numRowsAffected() override;
    bool prepare(const QString& query0) override;
    QSqlRecord record() const override;
    bool reset(const QString& sqlquery0) override;
    bool savePrepare(const QString& sqlquery0) override;
    void setActive(bool a0) override;
    void setAt(int at0) override;
    void setForwardOnly(bool forward0) override;
    void setLastError(const QSqlError& e0) override;
    void setNumericalPrecisionPolicy(QSql::NumericalPrecisionPolicy policy0) override;
    void setQuery(const QString& query0) override;
    void setSelect(bool s0) override;
    int size() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSqlResult_access : public QSqlResult
{
    void __qt_addBindValue_cref_QVariant_QSql_ParamType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject val0, jint type1);
    jint __qt_at_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_bindValueType_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring placeholder0) const;
    jint __qt_bindValueType_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0) const;
    jint __qt_bindingSyntax_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_boundValue_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring placeholder0) const;
    jobject __qt_boundValue_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0) const;
    jint __qt_boundValueCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_boundValueName_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0) const;
    jobject __qt_boundValues_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_clear(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_driver_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_executedQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasOutValues_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isActive_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isForwardOnly_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isSelect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isValid_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_lastError_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_lastQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_numericalPrecisionPolicy_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resetBindCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_bindValue_cref_QString_cref_QVariant_QSql_ParamType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring placeholder0, jobject val1, jint type2);
    void __qt_bindValue_int_cref_QVariant_QSql_ParamType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0, jobject val1, jint type2);
    jobject __qt_data_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint i0);
    void __qt_detachFromResultSet(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_exec(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_execBatch_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean arrayBind0);
    jboolean __qt_fetch_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint i0);
    jboolean __qt_fetchFirst(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_fetchLast(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_fetchNext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_fetchPrevious(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_handle_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isNull_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint i0);
    jobject __qt_lastInsertId_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_nextResult(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_numRowsAffected(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_prepare_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring query0);
    jobject __qt_record_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_reset_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring sqlquery0);
    jboolean __qt_savePrepare_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring sqlquery0);
    void __qt_setActive_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean a0);
    void __qt_setAt_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint at0);
    void __qt_setForwardOnly_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean forward0);
    void __qt_setLastError_cref_QSqlError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_setNumericalPrecisionPolicy_QSql_NumericalPrecisionPolicy(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint policy0);
    void __qt_setQuery_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring query0);
    void __qt_setSelect_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean s0);
    jint __qt_size(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    static inline const std::type_info& __registerEnumTypeInfo_BindingSyntax() {
        return RegistryAPI::registerEnumTypeInfo<QSqlResult::BindingSyntax>("QSqlResult::BindingSyntax", "io/qt/sql/QSqlResult$BindingSyntax");
    }
    static inline const std::type_info& __registerEnumTypeInfo_VirtualHookOperation() {
        return RegistryAPI::registerEnumTypeInfo<QSqlResult::VirtualHookOperation>("QSqlResult::VirtualHookOperation", "io/qt/sql/QSqlResult$VirtualHookOperation");
    }
};

#endif // QSQLRESULT_SHELL_H
